# Arora
Arora is a package for working with sleep diagnostic data. The package is currently still in early development.

It provides essential features for EDF file processing of sleep data such as
- Segmenting measurements
- Analyzing data through plots and graphs
- Processing data with various mathematical functions

You can get to know more in our official documentation.